package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.taskManager.Event
import de.fraunhofer.iem.dataprovider.taskManager.GitCloneDone
import org.eclipse.jgit.api.Git
import java.nio.file.Paths


data class GitProject(val name: String, val uri: String)
class CloneGitTask(
    private val gitProject: GitProject,
    override val responseChannel: suspend (task: Event) -> Unit,
    private val outputPath: String,
) : Task() {

    override suspend fun execute() {
        logger.info("Cloning ${gitProject.name}")

        val outputDirectory = Paths.get(outputPath, "${gitProject.name}-${taskID}")
        val git: Git = Git.cloneRepository()
            .setURI(gitProject.uri)
            .setDirectory(outputDirectory.toFile())
            .call()
        git.close()

        responseChannel(GitCloneDone(taskID, outputDirectory.toString()))

        logger.info("Finished cloning ${gitProject.name}")
    }
}