package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.gitlab.GitConfiguration
import de.fraunhofer.iem.dataprovider.taskManager.Event
import de.fraunhofer.iem.dataprovider.taskManager.GetGitlabProjectDone
import org.gitlab4j.api.GitLabApi


class GetGitlabProjectTask(
    private val repoId: Long, private val gitlabConfiguration: GitConfiguration,
    override val responseChannel: suspend (task: Event) -> Unit
) : Task() {


    private val gitlabApi: GitLabApi = GitLabApi(gitlabConfiguration.host, gitlabConfiguration.accessToken)

    override suspend fun execute() {
        logger.info("Gitlab config ${gitlabConfiguration.host} ${gitlabConfiguration.accessToken}")

        val project = gitlabApi.projectApi.getProject(repoId)
        logger.info(project.toString())
        val projectUri = project.httpUrlToRepo
        val gitProject = GitProject(project.path, projectUri)

        responseChannel(GetGitlabProjectDone(taskID, gitProject))

        logger.info("Retrieved project ${project.path} and url $projectUri")
    }
}
